condenseTrees: Condense a set of equally parsimonious node labels into a...

View source: R/Plotting.R

condenseTreesR Documentation

Condense a set of equally parsimonious node labels into a single tree

Description

condenseTrees Condenses a set of equally parsimonious node labels into a single tree

Usage

condenseTrees(trees, states, palette = NULL)

Arguments

trees

List of the same tree with equally parsimonious labels

states

States in model

palette

Named vector with a color per state

Value

a phylo object representing all represented internal node states


dowser documentation built on Sept. 16, 2026, 9:07 a.m.