exportTrees: Exports the phylogenetic trees from the airrClone object

View source: R/IO.R

exportTreesR Documentation

Exports the phylogenetic trees from the airrClone object

Description

exportTrees Exports phylogenetic trees

Usage

exportTrees(clones, filepath, tree_column = "trees", ...)

Arguments

clones

tibble airrClone objects, the output of getTrees or getTimeTrees

filepath

The file path for where the trees will be saved

tree_column

The name of the column that contains the trees

...

additional arguments to be passed


dowser documentation built on Aug. 20, 2026, 5:06 p.m.