getSubTaxa: Get the tip labels as part of a clade defined by an internal...

View source: R/TreeFunctions.R

getSubTaxaR Documentation

Get the tip labels as part of a clade defined by an internal node

Description

getSubTaxa Gets the tip labels from a clade

Usage

getSubTaxa(node, tree)

Arguments

node

node number that defines the target clade

tree

phylo object

Value

A vector containing tip labels of the clade

Examples

# Get taxa from all subtrees
## Not run: 
data(BiopsyTrees)
tree <- BiopsyTrees$trees[[8]]
all_subtrees <- lapply(1:length(tree$nodes), function(x)getSubTaxa(x, tree))

## End(Not run)

dowser documentation built on Aug. 20, 2026, 5:06 p.m.