installPythonDependencies: installPythonDependencies Checks for and installs the Python...

View source: R/Germlines.R

installPythonDependenciesR Documentation

installPythonDependencies Checks for and installs the Python dependencies for UCA estimation

Description

installPythonDependencies Checks for and installs the Python dependencies for UCA estimation

Usage

installPythonDependencies(python = "python3")

Arguments

python

Specify the python call for your system. This is the call on command line that issues the python you want to use. "python3" by default.


dowser documentation built on Aug. 20, 2026, 5:06 p.m.