| plotMSA | R Documentation |
Simple function for plotting multiple sequence alignments input can be either nucleotide or AA and contain ambiguous characters
plotMSA(
data,
id,
seq,
seq_type = c("nt", "aa"),
text_size = 1.5,
palette = NULL
)
data |
Data table with sequences |
id |
column name of sequence IDs (order will be preserved) |
seq |
column name of sequence data to be plotted |
seq_type |
sequence type in |
text_size |
size of sequence alignment text |
palette |
named vector of color for each character type in alignment, otherwise default nt or aa palette will be used |
a ggplot2-formatted multiple sequence alignment plot
getSeqPath
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.