setNodeDivergences: For each node in nodes list, store the divergence from the...

View source: R/TreeFunctions.R

setNodeDivergencesR Documentation

For each node in nodes list, store the divergence from the UCA

Description

For each node in nodes list, store the divergence from the UCA

Usage

setNodeDivergences(tree)

Arguments

tree

A phylo object with nodes list

Value

phylo with node list and divergences set


dowser documentation built on Aug. 20, 2026, 5:06 p.m.