| writeFasta | R Documentation |
writeFasta Write a fasta file of sequences given a
named list of sequenceswriteFasta Write a fasta file of sequences given a
named list of sequences
writeFasta(seqs, file)
seqs |
named list of sequences (output from |
file |
FASTA file for output |
File of FASTA formatted sequences
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.