buildAllClonalGermlines Determines and builds all possible germlines for a clone
buildAllClonalGermlines(
receptors,
references,
chain = "IGH",
use_regions = FALSE,
vonly = FALSE,
seq = "sequence_alignment",
id = "sequence_id",
clone = "clone_id",
v_call = "v_call",
j_call = "j_call",
v_germ_start = "v_germline_start",
v_germ_end = "v_germline_end",
v_germ_length = "v_germline_length",
d_germ_start = "d_germline_start",
d_germ_end = "d_germline_end",
d_germ_length = "d_germline_length",
j_germ_start = "j_germline_start",
j_germ_end = "j_germline_end",
j_germ_length = "j_germline_length",
np1_length = "np1_length",
np2_length = "np2_length",
j_germ_aa_length = "j_germline_aa_length",
amino_acid = FALSE,
...
)A data frame with all possible reconstructed germlines
AIRR-table containing sequences from one clone
Full list of reference segments, see readIMGT
chain in references being analyzed
Return string of VDJ regions? (optional)
Return germline of only v segment?
Column name for sequence alignment
Column name for sequence ID
Column name for clone ID
Column name for V gene segment gene call
Column name for J gene segment gene call
Column name of index of V segment start within germline
Column name of index of V segment end within germline
Column name of index of V segment length within germline
Column name of index of D segment start within germline
Column name of index of D segment end within germline
Column name of index of D segment length within germline
Column name of index of J segment start within germline
Column name of index of J segment end within germline
Column name of index of J segment length within germline
Column name in receptor specifying np1 segment length
Column name in receptor specifying np2 segment length
Column name of J segment amino acid length (if amino_acid=TRUE)
Perform reconstruction on amino acid sequence (experimental)
Additional arguments passed to buildGermline
createAllGermlines buildGermline, stitchVDJ