View source: R/TreeFunctions.R
| checkNodeDivergences | R Documentation |
For each node in nodes list, check that the current divergence is the same as previously reported
checkNodeDivergences(tree, stop = TRUE, catch_null = TRUE)
tree |
A |
stop |
Throw an error if divergences not equal |
catch_null |
Should null divergence values count as mismatches? |
TRUE or FALSE depening on whether node divergences are consistent if stop=TRUE, a FALSE value will cause an error
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.