For each node in nodes list, check that the current divergence is the same as previously reported
checkNodeDivergences(tree, stop = TRUE, catch_null = TRUE)TRUE or FALSE depening on whether node divergences are consistent if stop=TRUE, a FALSE value will cause an error
A phylo object with nodes list
Throw an error if divergences not equal
Should null divergence values count as mismatches?