getDiffPoints
getDiffPoints(
data,
trait,
height = "height",
verbose = FALSE,
tip_traits = NULL,
eo_adjust = FALSE,
eo_type = NULL,
full_posterior = FALSE,
summarize = TRUE,
nproc = 1
)a tibble containing trees column from getTimeTrees
column name of the trait of interest
which height value to return
print out info during run
vector of other traits to include for each tip. Must have been also specified as traits in formatClones.
adjust heights using expectOccupancies. Recommended if EO model used, requires eo_type to specify the type whose occupancy is tracked)
if eo_adjust, trait value described by expectedOccupancies (typically state 1 of 2)
Computer statistics using the full posterior distribution of trees?
if full_posterior=TRUE, summarize results or return the full table?
Number of cores to use (parallelizes by row of input data object)
Returns a data frame where each row is a tip in each tree clone_id = clone id for that tree tip = tip name tip_tip = trait value for that tip tip_height = height value for that tip diff_node = most recent ancestor node with different trait value, or root root = 1 if at root node, 0 otherwise node_type = type of diff_node, will be "root" if at root node node_height = height of diff_node <other columns> copied over from airrClone object for each tip
if (FALSE) dp = getDiffPoints(data, "location", verbose=TRUE,
eo_adjust=TRUE, eo_type="germinal_center")
Run the code above in your browser using DataLab