View source: R/TreeFunctions.R
| getSeqPath | R Documentation |
Return all sequences along the tree from the germline to a specified node
getSeqPath(
data,
node,
tree = NULL,
clone = NULL,
gaps = TRUE,
translate = FALSE,
rm_x_aa = FALSE,
dot_notation = FALSE,
verbose = FALSE
)
data |
a tibble of |
node |
numeric node in tree (see details) |
tree |
a |
clone |
if |
gaps |
add IMGT gaps to output sequences? |
translate |
Tranlate into amino acids? |
rm_x_aa |
Remove amino acids translated to X |
dot_notation |
Represent sites with germline character as "." and ambiguous sites as "?" |
verbose |
print out extra information? |
A data table where each row shows a node/node id, with that node's sequence(s) in the remaining columns with respective locus labels.
getNodeSeq getAllSeqs dfToFasta
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.