Return all sequences along the tree from the germline to a specified node
getSeqPath(
data,
node,
tree = NULL,
clone = NULL,
gaps = TRUE,
translate = FALSE,
rm_x_aa = FALSE,
dot_notation = FALSE,
verbose = FALSE
)A data table where each row shows a node/node id, with that node's sequence(s) in the remaining columns with respective locus labels.
a tibble of airrClone objects, the output of
getTrees
numeric node in tree (see details)
a phylo tree object containing node
if tree not specified, supply clone ID in data
add IMGT gaps to output sequences?
Tranlate into amino acids?
Remove amino acids translated to X
Represent sites with germline character as "." and ambiguous sites as "?"
print out extra information?
getNodeSeq getAllSeqs dfToFasta