ignore vector) having ESS
greater than or equal to the specified ess_cutoffgetTimeTreesIterate Iteratively resume getTimeTrees til convergence.
getTimeTreesIterate(
clones,
template,
beast,
dir,
id,
time,
iterations = 10,
ess_cutoff = 200,
burnin = 10,
ignore = c("traitfrequencies"),
continue = FALSE,
posterior = c("none", "all", "parameters", "trees_with_traits", "trees"),
trait = NULL,
nproc = 1,
quiet = 0,
asr = FALSE,
low_ram = TRUE,
trim_ids = FALSE,
...
)A tibble of tidytree and airrClone objects.
a tibble of airrClone objects, the output of
formatClones
XML template
location of beast binary directory (beast/bin)
directory where temporary files will be placed.
unique identifer for this analysis
Name of sample time column
Maximum number of times to resume MCMC chain
Minimum number of ESS for all parameters
Burnin percent (default 10)
Vector of parameters to ignore for ESS calculation
If TRUE, will check for iteration folder and resume from last iteration if found (default FALSE)
Read un full distribution of parameters and trees? Can be "none" to just have summary objects, "all" to have parameters, trees, and trees_with_traits, or a vector with the desired combination of "parameters", "trees_with_traits", and "trees".
Trait column to be used
Number of cores for parallelization. At most 1 core/tree can be used.
quiet notifications if > 0
Log ancestral sequences?
run with less memory (slightly slower)
remove last _ group from tips?
Additional arguments for getTimeTrees
For a full list of options (of which there are many more), see getTimeTrees
For examples and vignettes, see https://dowser.readthedocs.io