getTreesAndUCAs Construct trees and infer the UCA
getTreesAndUCAs(
clones,
data,
exec,
model_folder,
references,
dir = NULL,
model_folder_igk = NULL,
model_folder_igl = NULL,
partition = "single",
repertoire_wide = FALSE,
python = "python3",
id = "sample",
max_iters = 100,
nproc = 1,
rm_temp = TRUE,
quiet = 0,
chain = "H",
clone = "clone_id",
cell = "cell_id",
subsample_size = NA,
subsampling_method = c("random", "weighted", "least_mutated"),
search = c("codon", "nt"),
resolve_vj = FALSE,
fix_vj_in_cdr3 = TRUE,
fill_partials = TRUE,
split_light = FALSE,
...
)An airrClone object with trees and the inferred UCA
AIRR-table containing sequences formatClones
The AIRR-table that was used to make the clones object.
File path to the tree building executable
The file path to the OLGA default model files for heavy chains
Reference genes. See readIMGT
The file path of the directory of where data is saved. NULL is default.
The file path to the OLGA default model files for IGK
The file path to the OLGA default model files for IGL
The partition model to use with IgPhyML. "single" is the default.
Build trees using parameters inferred from the entire dataset?
Specify the python call for your system. This is the call on command line that issues the python you want to use. "python3" by default.
The run ID, sample by default
The maximum number of iterations to run before ending. 100 by default
The number of cores to use
Remove the generated files?
Amount of noise to print out
Set to HL to use both heavy and light chain sequences
The name of the clone id column used in formatClones.
The name of the cell id in the AIRR table used to generate formatClones
The amount that the clone should be sampled down to. By default this is NA to not induce subsampling.
How to subsample. Methods include 'random', 'weighted', and 'least_mutated'. The later two methods require 'mu_freq' to be passed as a trait when running
Search codon or nt space
Resolve the V and J gene annotations within each clone?
Check if the inferred V/J lengths go into the inferred cdr3 region and adjust accordingly.
A logical that will fill in the V and J UCAs of clones that have partial V/J sequence alignments
A logical that indicates if different light chain groups should be used to further split a clone (recommended for paired data)
Additional arguments passed to various other functions like getTrees and buildGermline
Return object adds/edits following columns:
trees: The phylogenies associated with each clone
UCA: The inferred UCA
getTrees