Learn R Programming

dowser (version 2.5.1)

installPythonDependencies: installPythonDependencies Checks for and installs the Python dependencies for UCA estimation

Description

installPythonDependencies Checks for and installs the Python dependencies for UCA estimation

Usage

installPythonDependencies(python = "python3")

Arguments

python

Specify the python call for your system. This is the call on command line that issues the python you want to use. "python3" by default.