installPythonDependencies Checks for and installs the Python dependencies for UCA estimation
installPythonDependencies(python = "python3")Specify the python call for your system. This is the call on command line that issues the python you want to use. "python3" by default.