| mapSubtrees | R Documentation |
Get a map of nodes from one
mapSubtrees(treea, treeb)
treea |
First phylo object |
treeb |
Second phylo object |
Returns a vector in which each position is the numerical node number in treea, and the value is the corresponding node number in treeb So node 1 in treea corresponds to result[1] in treeb
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.