Learn R Programming

dowser (version 2.5.1)

mapSubtrees: Get a map of nodes from one

Description

Get a map of nodes from one

Usage

mapSubtrees(treea, treeb)

Arguments

treea

First phylo object

treeb

Second phylo object

Details

Returns a vector in which each position is the numerical node number in treea, and the value is the corresponding node number in treeb So node 1 in treea corresponds to result[1] in treeb