Simple function for plotting multiple sequence alignments input can be either nucleotide or AA and contain ambiguous characters
plotMSA(
data,
id,
seq,
seq_type = c("nt", "aa"),
text_size = 1.5,
palette = NULL
)a ggplot2-formatted multiple sequence alignment plot
Data table with sequences
column name of sequence IDs (order will be preserved)
column name of sequence data to be plotted
sequence type in seq column, nucleotide (nt) or amino acid (aa)
size of sequence alignment text
named vector of color for each character type in alignment, otherwise default nt or aa palette will be used
getSeqPath