Learn R Programming

dowser (version 2.5.1)

setNodeDivergences: For each node in nodes list, store the divergence from the UCA

Description

For each node in nodes list, store the divergence from the UCA

Usage

setNodeDivergences(tree)

Value

phylo with node list and divergences set

Arguments

tree

A phylo object with nodes list